==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Polygon_mesh_processing/group__PkgPolygonMeshProcessingConcepts.js <==
var group__PkgPolygonMeshProcessingConcepts =
[
    [ "PMPCorefinementVisitor", "classPMPCorefinementVisitor.html", [
      [ "face_descriptor", "classPMPCorefinementVisitor.html#a72d353688616d1746e2dd8990a4c3803", null ],
      [ "halfedge_descriptor", "classPMPCorefinementVisitor.html#a9f5a635e082e2a12dcc98baeffe7efac", null ],
      [ "Triangle_mesh", "classPMPCorefinementVisitor.html#a1ecf573a53a439e94ff33d0619efb390", null ],
      [ "add_retriangulation_edge", "classPMPCorefinementVisitor.html#ab819d40a2bda062d883ac2a6fb62e8f8", null ],
      [ "after_edge_copy", "classPMPCorefinementVisitor.html#aa606ff79672e2542c1fabb4443688b8a", null ],
      [ "after_edge_duplicated", "classPMPCorefinementVisitor.html#a515678d067926aa9df04677a3f1df6b4", null ],
      [ "after_edge_split", "classPMPCorefinementVisitor.html#af2f61a0a46ba27c8bc011838fc987058", null ],
      [ "after_face_copy", "classPMPCorefinementVisitor.html#a9adc3c945d5965ca82e58af5e01a0652", null ],
      [ "after_subface_created", "classPMPCorefinementVisitor.html#adc77b92dd3b34ecf38256843f732c2d7", null ],
      [ "after_subface_creations", "classPMPCorefinementVisitor.html#a7bdf1b81fd005654e19fc344aa026863", null ],
      [ "after_vertex_copy", "classPMPCorefinementVisitor.html#aad3a4eade447e236ec993fc05cb8020e", null ],
      [ "before_edge_copy", "classPMPCorefinementVisitor.html#aceccd3914adea586d117b628e0fcc1e2", null ],
      [ "before_edge_duplicated", "classPMPCorefinementVisitor.html#ae78af2adbbbb4d0c9b6a80a0688e6719", null ],
      [ "before_edge_split", "classPMPCorefinementVisitor.html#a2c228867e23eef9b90c2826d303ca8a5", null ],
      [ "before_face_copy", "classPMPCorefinementVisitor.html#a8a16fd716c8be00a13ead5c7b6656f23", null ],
      [ "before_subface_created", "classPMPCorefinementVisitor.html#aac745bdd3bd7f3ca4d0fd6ced6f4fca8", null ],
      [ "before_subface_creations", "classPMPCorefinementVisitor.html#a68525c003867c6cbf68f522d949e6a15", null ],
      [ "before_vertex_copy", "classPMPCorefinementVisitor.html#ae0d4dfeedf82a857b1910f351231443e", null ],
      [ "classify_intersection_free_patches", "classPMPCorefinementVisitor.html#a1bc3aa40f990e83bb6b5cd7f6ddffc42", null ],
      [ "classify_patches", "classPMPCorefinementVisitor.html#af2eae8d512832aa4218af4f91a30e045", null ],
      [ "detect_patches", "classPMPCorefinementVisitor.html#aaaf8fed0acc326dcf50496d5649dcc7a", null ],
      [ "edge_face_intersections_step", "classPMPCorefinementVisitor.html#a436717c3d86f8858edcd83eed81b733b", null ],
      [ "edge_split", "classPMPCorefinementVisitor.html#a7e109ecde7ed610a1af1c53d4d8cffe9", null ],
      [ "end_building_output", "classPMPCorefinementVisitor.html#acdcad95153212809d7cb86a4e4dbacfb", null ],
      [ "end_filtering_intersections", "classPMPCorefinementVisitor.html#aa8b47a99b7ffa3fad218015286a24fde", null ],
      [ "end_handling_edge_face_intersections", "classPMPCorefinementVisitor.html#ae2943fc8d6bf1b3f9c17b3b9c19c935c", null ],
      [ "end_handling_intersection_of_coplanar_faces", "classPMPCorefinementVisitor.html#a0da4738da462d803465d09987d315f21", null ],
      [ "end_triangulating_faces", "classPMPCorefinementVisitor.html#adfcee239435f91731bab7908e52c9449", null ],
      [ "filter_coplanar_edges", "classPMPCorefinementVisitor.html#ad7346675f069294e78d3425a44f09978", null ],
      [ "in_place_operation", "classPMPCorefinementVisitor.html#aa8521c2516475ac2fe9115e381b30ff7", null ],
      [ "in_place_operations", "classPMPCorefinementVisitor.html#a2a2d75da057dcdaf3232c579329ad85b", null ],
      [ "intersection_edge_copy", "classPMPCorefinementVisitor.html#adcd05ea07c741b505c02902cb3b803d9", null ],
      [ "intersection_of_coplanar_faces_step", "classPMPCorefinementVisitor.html#a02669432c89cfeaa2c69446afda07f1e", null ],
      [ "intersection_point_detected", "classPMPCorefinementVisitor.html#acd13f3e9b14a96191d1cc07f0014897f", null ],
      [ "new_vertex_added", "classPMPCorefinementVisitor.html#a98422d4a6689cbaaef3c107a1be439c6", null ],
      [ "out_of_place_operation", "classPMPCorefinementVisitor.html#a473a93975a089c19c695aeff921e8964", null ],
      [ "progress_filtering_intersections", "classPMPCorefinementVisitor.html#a8bc4cb77915694e7a3dc6428305323d8", null ],
      [ "start_building_output", "classPMPCorefinementVisitor.html#a1ca9d8d55b278fc1ae699a8cff6fb809", null ],
      [ "start_filtering_intersections", "classPMPCorefinementVisitor.html#af44d93902c3e1f4afa11f7a1d12b2624", null ],
      [ "start_handling_edge_face_intersections", "classPMPCorefinementVisitor.html#a0d160a1573cd93115b300ec86c9221d8", null ],
      [ "start_handling_intersection_of_coplanar_faces", "classPMPCorefinementVisitor.html#ad742db01b774aed6b3edca64e5795ee3", null ],
      [ "start_triangulating_faces", "classPMPCorefinementVisitor.html#adf3a799f88e90df66b9f44468c996bd6", null ],
      [ "triangulating_faces_step", "classPMPCorefinementVisitor.html#a9499eac0ae81a5a469e28c3fdc41e2b0", null ]
    ] ],
    [ "PMPDistanceTraits", "classPMPDistanceTraits.html", [
      [ "Compute_squared_area_3", "classPMPDistanceTraits.html#a082fe010f412a3c1d5e05221d7227ae4", null ],
      [ "Compute_squared_length_3", "classPMPDistanceTraits.html#ab86db55e6f27755dacb4d9f88107a82d", null ],
      [ "Construct_scaled_vector_3", "classPMPDistanceTraits.html#a06c263c3c5b34f1053b024b9b8f78d7d", null ],
      [ "Construct_translated_point_3", "classPMPDistanceTraits.html#ace007a88453bcf18c2483e60a762859c", null ],
      [ "Construct_vector_3", "classPMPDistanceTraits.html#a704303a0d10efaa8a56a010d79346b25", null ],
      [ "FT", "classPMPDistanceTraits.html#a9e64c7865a0e71ab722055b8c29c50f0", null ],
      [ "Point_3", "classPMPDistanceTraits.html#a0a58e2b996d696ee50a92710848398e0", null ],
      [ "Vector_3", "classPMPDistanceTraits.html#aa94a729ff8bde9df89530b9e7bb6c722", null ],
      [ "compute_squared_area_3_object", "classPMPDistanceTraits.html#a2e308600f7483e3c31115a3d9f1f3567", null ],
      [ "compute_squared_length_3_object", "classPMPDistanceTraits.html#a92e4a7fe9191558e0a1e4476bd46b8de", null ],
      [ "construct_scaled_vector_3_object", "classPMPDistanceTraits.html#ab9eb3e91b2acf455018d89f7365c77df", null ],
      [ "construct_translated_point_3_object", "classPMPDistanceTraits.html#a694921d8f6fd04a12c03d38f25cf4948", null ],
      [ "construct_vector_3_object", "classPMPDistanceTraits.html#a3234aad71b22606d65aee122d8c46b38", null ]
    ] ],
    [ "PMPHolefillingVisitor", "classPMPHolefillingVisitor.html", [
      [ "cubic_step", "classPMPHolefillingVisitor.html#ad7d6765bce9c4a81435cd328a15c2ca1", null ],
      [ "end_cubic_phase", "classPMPHolefillingVisitor.html#a17eddb4a44998a76125154850a4f0b47", null ],
      [ "end_fair_phase", "classPMPHolefillingVisitor.html#a1552fad2934c7591f671ed6c8367e95f", null ],
      [ "end_planar_phase", "classPMPHolefillingVisitor.html#a5ba69027a93b3c8b9b45111d37a7fed0", null ],
      [ "end_quadratic_phase", "classPMPHolefillingVisitor.html#ab187c68ddb03eb66945d1ad26947fc8b", null ],
      [ "end_refine_phase", "classPMPHolefillingVisitor.html#ae1034b2fa9bfb7391d2733aecbee95c5", null ],
      [ "quadratic_step", "classPMPHolefillingVisitor.html#af85b6274f2a0a7a77cc657e8f80bd9c5", null ],
      [ "start_cubic_phase", "classPMPHolefillingVisitor.html#a144aaa0f9dc844264acbf72e6d9d85dd", null ],
      [ "start_fair_phase", "classPMPHolefillingVisitor.html#a183d85e93f3e08405afac9dc7596285f", null ],
      [ "start_planar_phase", "classPMPHolefillingVisitor.html#ad76ba26af056009bd312c9fc26b25ff0", null ],
      [ "start_quadratic_phase", "classPMPHolefillingVisitor.html#ad6ca046de37798640b58cdf3c626313f", null ],
      [ "start_refine_phase", "classPMPHolefillingVisitor.html#af44dc7491edfd311b8fa08afb0d82aa2", null ]
    ] ],
    [ "PMPPolygonSoupOrientationVisitor", "classPMPPolygonSoupOrientationVisitor.html", [
      [ "duplicated_vertex", "classPMPPolygonSoupOrientationVisitor.html#a8b5c0fe1538a5cc4c3c2c73aa10f5e29", null ],
      [ "link_connected_polygons", "classPMPPolygonSoupOrientationVisitor.html#a9937ae45797a68f4df72810fe903a434", null ],
      [ "non_manifold_edge", "classPMPPolygonSoupOrientationVisitor.html#ae343638a6011f52d23b472f602d49307", null ],
      [ "non_manifold_vertex", "classPMPPolygonSoupOrientationVisitor.html#a37e165c1ca3ae40cfc45c507336168fe", null ],
      [ "polygon_orientation_reversed", "classPMPPolygonSoupOrientationVisitor.html#a20deb5b24a3db638d29fb85810b53c5d", null ],
      [ "vertex_id_in_polygon_replaced", "classPMPPolygonSoupOrientationVisitor.html#a62f72578956f0c5c90c7a898b59814b3", null ]
    ] ],
    [ "PMPSelfIntersectionTraits", "classPMPSelfIntersectionTraits.html", [
      [ "Construct_segment_3", "classPMPSelfIntersectionTraits.html#ae490aafcda8ed998759842a67a57ca92", null ],
      [ "Construct_triangle_3", "classPMPSelfIntersectionTraits.html#a841af4ea980b4130a4fa477633bc4dcf", null ],
      [ "Do_intersect_3", "classPMPSelfIntersectionTraits.html#a0cd254de374b3b52dfa55268c99de276", null ],
      [ "Point_3", "classPMPSelfIntersectionTraits.html#adbd168594bb0dda280073cd886bcae5e", null ],
      [ "Segment_3", "classPMPSelfIntersectionTraits.html#a66f3a6d91df8b9708695119b8d588003", null ],
      [ "Triangle_3", "classPMPSelfIntersectionTraits.html#aec3c2d71b0d0197f7b991cf45954a6c5", null ],
      [ "construct_segment_3_object", "classPMPSelfIntersectionTraits.html#a5acba64c025984743f94c34c22992951", null ],
      [ "construct_triangle_3_object", "classPMPSelfIntersectionTraits.html#a8ee88a23743b2bcdbc3b423aabea1b5a", null ],
      [ "do_intersect_3_object", "classPMPSelfIntersectionTraits.html#aa93dab0a75993ba826708b1b4d25c429", null ]
    ] ],
    [ "PMPTriangulateFaceVisitor", "classPMPTriangulateFaceVisitor.html", [
      [ "face_descriptor", "classPMPTriangulateFaceVisitor.html#a25b9d941ff6faaa36bcf2031ff0ae14a", null ],
      [ "after_subface_created", "classPMPTriangulateFaceVisitor.html#a709576ece4862f7a9ae3d3a80e865211", null ],
      [ "after_subface_creations", "classPMPTriangulateFaceVisitor.html#a639708124560683968cbe9e7c5f5dd13", null ],
      [ "before_subface_creations", "classPMPTriangulateFaceVisitor.html#a90682678607fc5d677b505868ace6068", null ]
    ] ]
];

==> CGAL-6.0-doc_html.tar.xz: doc_html/Polygon_mesh_processing/group__PkgPolygonMeshProcessingConcepts.js <==
var group__PkgPolygonMeshProcessingConcepts =
[
    [ "PMPAutorefinementVisitor", "classPMPAutorefinementVisitor.html", [
      [ "new_subtriangle", "classPMPAutorefinementVisitor.html#ab2d0abdf3d2e9dc47640ca37f9737055", null ],
      [ "number_of_output_triangles", "classPMPAutorefinementVisitor.html#a2b7130b0c94651e21b6a3c4f2d3ec765", null ],
      [ "verbatim_triangle_copy", "classPMPAutorefinementVisitor.html#a454023769deabacd45540d8a5dcb27ab", null ]
    ] ],
    [ "PMPCorefinementVisitor", "classPMPCorefinementVisitor.html", [
      [ "face_descriptor", "classPMPCorefinementVisitor.html#a72d353688616d1746e2dd8990a4c3803", null ],
      [ "halfedge_descriptor", "classPMPCorefinementVisitor.html#a9f5a635e082e2a12dcc98baeffe7efac", null ],
      [ "Triangle_mesh", "classPMPCorefinementVisitor.html#a1ecf573a53a439e94ff33d0619efb390", null ],
      [ "add_retriangulation_edge", "classPMPCorefinementVisitor.html#ab819d40a2bda062d883ac2a6fb62e8f8", null ],
      [ "after_edge_copy", "classPMPCorefinementVisitor.html#aa606ff79672e2542c1fabb4443688b8a", null ],
      [ "after_edge_duplicated", "classPMPCorefinementVisitor.html#a515678d067926aa9df04677a3f1df6b4", null ],
      [ "after_edge_split", "classPMPCorefinementVisitor.html#af2f61a0a46ba27c8bc011838fc987058", null ],
      [ "after_face_copy", "classPMPCorefinementVisitor.html#a9adc3c945d5965ca82e58af5e01a0652", null ],
      [ "after_subface_created", "classPMPCorefinementVisitor.html#adc77b92dd3b34ecf38256843f732c2d7", null ],
      [ "after_subface_creations", "classPMPCorefinementVisitor.html#a7bdf1b81fd005654e19fc344aa026863", null ],
      [ "after_vertex_copy", "classPMPCorefinementVisitor.html#aad3a4eade447e236ec993fc05cb8020e", null ],
      [ "before_edge_copy", "classPMPCorefinementVisitor.html#aceccd3914adea586d117b628e0fcc1e2", null ],
      [ "before_edge_duplicated", "classPMPCorefinementVisitor.html#ae78af2adbbbb4d0c9b6a80a0688e6719", null ],
      [ "before_edge_split", "classPMPCorefinementVisitor.html#a2c228867e23eef9b90c2826d303ca8a5", null ],
      [ "before_face_copy", "classPMPCorefinementVisitor.html#a8a16fd716c8be00a13ead5c7b6656f23", null ],
      [ "before_subface_created", "classPMPCorefinementVisitor.html#aac745bdd3bd7f3ca4d0fd6ced6f4fca8", null ],
      [ "before_subface_creations", "classPMPCorefinementVisitor.html#a68525c003867c6cbf68f522d949e6a15", null ],
      [ "before_vertex_copy", "classPMPCorefinementVisitor.html#ae0d4dfeedf82a857b1910f351231443e", null ],
      [ "classify_intersection_free_patches", "classPMPCorefinementVisitor.html#a1bc3aa40f990e83bb6b5cd7f6ddffc42", null ],
      [ "classify_patches", "classPMPCorefinementVisitor.html#af2eae8d512832aa4218af4f91a30e045", null ],
      [ "detect_patches", "classPMPCorefinementVisitor.html#aaaf8fed0acc326dcf50496d5649dcc7a", null ],
      [ "edge_face_intersections_step", "classPMPCorefinementVisitor.html#a436717c3d86f8858edcd83eed81b733b", null ],
      [ "edge_split", "classPMPCorefinementVisitor.html#a7e109ecde7ed610a1af1c53d4d8cffe9", null ],
      [ "end_building_output", "classPMPCorefinementVisitor.html#acdcad95153212809d7cb86a4e4dbacfb", null ],
      [ "end_filtering_intersections", "classPMPCorefinementVisitor.html#aa8b47a99b7ffa3fad218015286a24fde", null ],
      [ "end_handling_edge_face_intersections", "classPMPCorefinementVisitor.html#ae2943fc8d6bf1b3f9c17b3b9c19c935c", null ],
      [ "end_handling_intersection_of_coplanar_faces", "classPMPCorefinementVisitor.html#a0da4738da462d803465d09987d315f21", null ],
      [ "end_triangulating_faces", "classPMPCorefinementVisitor.html#adfcee239435f91731bab7908e52c9449", null ],
      [ "filter_coplanar_edges", "classPMPCorefinementVisitor.html#ad7346675f069294e78d3425a44f09978", null ],
      [ "in_place_operation", "classPMPCorefinementVisitor.html#aa8521c2516475ac2fe9115e381b30ff7", null ],
      [ "in_place_operations", "classPMPCorefinementVisitor.html#a2a2d75da057dcdaf3232c579329ad85b", null ],
      [ "intersection_edge_copy", "classPMPCorefinementVisitor.html#adcd05ea07c741b505c02902cb3b803d9", null ],
      [ "intersection_of_coplanar_faces_step", "classPMPCorefinementVisitor.html#a02669432c89cfeaa2c69446afda07f1e", null ],
      [ "intersection_point_detected", "classPMPCorefinementVisitor.html#acd13f3e9b14a96191d1cc07f0014897f", null ],
      [ "new_vertex_added", "classPMPCorefinementVisitor.html#a98422d4a6689cbaaef3c107a1be439c6", null ],
      [ "out_of_place_operation", "classPMPCorefinementVisitor.html#a473a93975a089c19c695aeff921e8964", null ],
      [ "progress_filtering_intersections", "classPMPCorefinementVisitor.html#a8bc4cb77915694e7a3dc6428305323d8", null ],
      [ "start_filtering_intersections", "classPMPCorefinementVisitor.html#af44d93902c3e1f4afa11f7a1d12b2624", null ],
      [ "start_handling_edge_face_intersections", "classPMPCorefinementVisitor.html#a0d160a1573cd93115b300ec86c9221d8", null ],
      [ "start_handling_intersection_of_coplanar_faces", "classPMPCorefinementVisitor.html#ad742db01b774aed6b3edca64e5795ee3", null ],
      [ "start_triangulating_faces", "classPMPCorefinementVisitor.html#adf3a799f88e90df66b9f44468c996bd6", null ],
      [ "triangulating_faces_step", "classPMPCorefinementVisitor.html#a9499eac0ae81a5a469e28c3fdc41e2b0", null ]
    ] ],
    [ "PMPDistanceTraits", "classPMPDistanceTraits.html", [
      [ "Compute_squared_area_3", "classPMPDistanceTraits.html#a082fe010f412a3c1d5e05221d7227ae4", null ],
      [ "Compute_squared_length_3", "classPMPDistanceTraits.html#ab86db55e6f27755dacb4d9f88107a82d", null ],
      [ "Construct_scaled_vector_3", "classPMPDistanceTraits.html#a06c263c3c5b34f1053b024b9b8f78d7d", null ],
      [ "Construct_translated_point_3", "classPMPDistanceTraits.html#ace007a88453bcf18c2483e60a762859c", null ],
      [ "Construct_vector_3", "classPMPDistanceTraits.html#a704303a0d10efaa8a56a010d79346b25", null ],
      [ "FT", "classPMPDistanceTraits.html#a9e64c7865a0e71ab722055b8c29c50f0", null ],
      [ "Point_3", "classPMPDistanceTraits.html#a0a58e2b996d696ee50a92710848398e0", null ],
      [ "Vector_3", "classPMPDistanceTraits.html#aa94a729ff8bde9df89530b9e7bb6c722", null ]
    ] ],
    [ "PMPHolefillingVisitor", "classPMPHolefillingVisitor.html", [
      [ "cubic_step", "classPMPHolefillingVisitor.html#ad7d6765bce9c4a81435cd328a15c2ca1", null ],
      [ "end_cubic_phase", "classPMPHolefillingVisitor.html#a17eddb4a44998a76125154850a4f0b47", null ],
      [ "end_fair_phase", "classPMPHolefillingVisitor.html#a1552fad2934c7591f671ed6c8367e95f", null ],
      [ "end_planar_phase", "classPMPHolefillingVisitor.html#a5ba69027a93b3c8b9b45111d37a7fed0", null ],
      [ "end_quadratic_phase", "classPMPHolefillingVisitor.html#ab187c68ddb03eb66945d1ad26947fc8b", null ],
      [ "end_refine_phase", "classPMPHolefillingVisitor.html#ae1034b2fa9bfb7391d2733aecbee95c5", null ],
      [ "quadratic_step", "classPMPHolefillingVisitor.html#af85b6274f2a0a7a77cc657e8f80bd9c5", null ],
      [ "start_cubic_phase", "classPMPHolefillingVisitor.html#a144aaa0f9dc844264acbf72e6d9d85dd", null ],
      [ "start_fair_phase", "classPMPHolefillingVisitor.html#a183d85e93f3e08405afac9dc7596285f", null ],
      [ "start_planar_phase", "classPMPHolefillingVisitor.html#ad76ba26af056009bd312c9fc26b25ff0", null ],
      [ "start_quadratic_phase", "classPMPHolefillingVisitor.html#ad6ca046de37798640b58cdf3c626313f", null ],
      [ "start_refine_phase", "classPMPHolefillingVisitor.html#af44dc7491edfd311b8fa08afb0d82aa2", null ]
    ] ],
    [ "PMPPolygonSoupOrientationVisitor", "classPMPPolygonSoupOrientationVisitor.html", [
      [ "duplicated_vertex", "classPMPPolygonSoupOrientationVisitor.html#a8b5c0fe1538a5cc4c3c2c73aa10f5e29", null ],
      [ "link_connected_polygons", "classPMPPolygonSoupOrientationVisitor.html#a9937ae45797a68f4df72810fe903a434", null ],
      [ "non_manifold_edge", "classPMPPolygonSoupOrientationVisitor.html#ae343638a6011f52d23b472f602d49307", null ],
      [ "non_manifold_vertex", "classPMPPolygonSoupOrientationVisitor.html#a37e165c1ca3ae40cfc45c507336168fe", null ],
      [ "polygon_orientation_reversed", "classPMPPolygonSoupOrientationVisitor.html#a20deb5b24a3db638d29fb85810b53c5d", null ],
      [ "vertex_id_in_polygon_replaced", "classPMPPolygonSoupOrientationVisitor.html#a62f72578956f0c5c90c7a898b59814b3", null ]
    ] ],
    [ "PMPSelfIntersectionTraits", "classPMPSelfIntersectionTraits.html", [
      [ "Construct_segment_3", "classPMPSelfIntersectionTraits.html#ae490aafcda8ed998759842a67a57ca92", null ],
      [ "Construct_triangle_3", "classPMPSelfIntersectionTraits.html#a841af4ea980b4130a4fa477633bc4dcf", null ],
      [ "Do_intersect_3", "classPMPSelfIntersectionTraits.html#a0cd254de374b3b52dfa55268c99de276", null ],
      [ "Point_3", "classPMPSelfIntersectionTraits.html#adbd168594bb0dda280073cd886bcae5e", null ],
      [ "Segment_3", "classPMPSelfIntersectionTraits.html#a66f3a6d91df8b9708695119b8d588003", null ],
      [ "Triangle_3", "classPMPSelfIntersectionTraits.html#aec3c2d71b0d0197f7b991cf45954a6c5", null ]
    ] ],
    [ "PMPSizingField", "classPMPSizingField.html", [
      [ "FT", "classPMPSizingField.html#af2b8137aed4d180e0b4f4a283999ee2d", null ],
      [ "halfedge_descriptor", "classPMPSizingField.html#acb8d0afb2a0acec38cbfd1741b5dcc98", null ],
      [ "Point_3", "classPMPSizingField.html#a557a97827ef40f6d6fb866a1a749e6ab", null ],
      [ "PolygonMesh", "classPMPSizingField.html#ac91844c2049943895fbcb1e6017be89c", null ],
      [ "vertex_descriptor", "classPMPSizingField.html#a0a0ee7e5a2c3bc442a9350a02b1b2f24", null ],
      [ "at", "classPMPSizingField.html#a998f26cbc6ac3edbfa4703847ef03dd1", null ],
      [ "is_too_long", "classPMPSizingField.html#a70cc54d401f84a313ebc54d957fd247a", null ],
      [ "is_too_short", "classPMPSizingField.html#aaf135545d27f1352b59e872cc6500ac8", null ],
      [ "register_split_vertex", "classPMPSizingField.html#a42a21767d6e96fc6645edf1c6d312d1c", null ],
      [ "split_placement", "classPMPSizingField.html#a760182d3f098d5c709c7e47a9653acf0", null ]
    ] ],
    [ "PMPTriangulateFaceVisitor", "classPMPTriangulateFaceVisitor.html", [
      [ "face_descriptor", "classPMPTriangulateFaceVisitor.html#a25b9d941ff6faaa36bcf2031ff0ae14a", null ],
      [ "after_subface_created", "classPMPTriangulateFaceVisitor.html#a709576ece4862f7a9ae3d3a80e865211", null ],
      [ "after_subface_creations", "classPMPTriangulateFaceVisitor.html#a639708124560683968cbe9e7c5f5dd13", null ],
      [ "before_subface_creations", "classPMPTriangulateFaceVisitor.html#a90682678607fc5d677b505868ace6068", null ]
    ] ]
];
